==> haskell-retry-0.9.3.1-147.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-retry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 retry
version:              0.9.3.1
visibility:           public
id:                   retry-0.9.3.1-HEvs5AQWwJi8IsgEJKYYst
key:                  retry-0.9.3.1-HEvs5AQWwJi8IsgEJKYYst
license:              BSD-3-Clause
copyright:            Ozgun Ataman, Soostone Inc
maintainer:           ozgun.ataman@soostone.com
author:               Ozgun Ataman
homepage:             http://github.com/Soostone/retry
synopsis:             Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.

category:             Control
abi:                  b9ac0c8bbd9937f54839c86607e334ef
exposed:              True
exposed-modules:      Control.Retry UnliftIO.Retry
import-dirs:          /usr/lib/ghc-9.6.6/site-local/retry-0.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/retry-0.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/retry-0.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-retry
hs-libraries:         HSretry-0.9.3.1-HEvs5AQWwJi8IsgEJKYYst
depends:
    base-4.18.2.1 exceptions-0.10.7 ghc-prim-0.10.0 mtl-2.3.1
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:   /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html:         /usr/share/doc/haskell-retry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-retry-0.9.3.1-148-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-retry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 retry
version:              0.9.3.1
visibility:           public
id:                   retry-0.9.3.1-FYTMxXzp6ILABIm5Dm7RjL
key:                  retry-0.9.3.1-FYTMxXzp6ILABIm5Dm7RjL
license:              BSD-3-Clause
copyright:            Ozgun Ataman, Soostone Inc
maintainer:           ozgun.ataman@soostone.com
author:               Ozgun Ataman
homepage:             http://github.com/Soostone/retry
synopsis:             Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.

category:             Control
abi:                  0e94c6d13650e7be73f87f69a7663c4a
exposed:              True
exposed-modules:      Control.Retry UnliftIO.Retry
import-dirs:          /usr/lib/ghc-9.6.6/site-local/retry-0.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/retry-0.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/retry-0.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-retry
hs-libraries:         HSretry-0.9.3.1-FYTMxXzp6ILABIm5Dm7RjL
depends:
    base-4.18.2.1 exceptions-0.10.7 ghc-prim-0.10.0 mtl-2.3.1
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:   /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html:         /usr/share/doc/haskell-retry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
